Scoutr has support for three providers:

- [AWS DynamoDB](#aws-dynamodb)
- [GCP Firestore](#gcp-firestore)
- [MongoDB](#mongodb)

### AWS DynamoDB
The [DynamoDB](https://aws.amazon.com/dynamodb/) provider is implemented in the `DynamoAPI` class.

### GCP Firestore
The [Firestore](https://cloud.google.com/firestore/) provider is implemented in the `FirestoreAPI` class.

### MongoDB
The [MongoDB](https://www.mongodb.com/) provider is implemented in the `MongoAPI` class.
